==> testx-http-keywords-0.11.1.tgz: package/README.md <==
testx-http-keywords
=====

A library that extends testx with keywords for sending basic http requests. This library is packaged as a npm package

## How does it work
From the directory of the art code install the package as follows:
```sh
npm install testx-http-keywords --save
```

After installing the package add the keywords to your protractor config file as follows:

```
testx.keywords.add(require('testx-http-keywords'))
```

## Keywords

| Keyword                   | Argument name | Argument value  | Description | Supports repeating arguments |
| ----------------------    | ------------- | --------------- |------------ | ---------------------------- |
| send http [optional request method] request         |               |                 | send a http POST request and check if the response status code is 200 |  |
|                           | url           | relative url to which the request will be sent || No |
|                           | method        | request method  | Optional. Valid values are **get**, **post**, **put** and **delete**. Defaults to **get**. It is also possible to put the methid in the keyword, as in **send http post request** or **send http delete request** instead of providing this argument. | No |
|                           | json          | a valid JSON string that contains the body of the request | Optional. Defaults to an empty object | No |
|                           | headers       | custom headers | Optional. Semicolon or new line-separated string of '='-separated key-value pairs. For example "User-Agent=testx;Something-Else='value with spaces'"| No |
|                           | expected status code   | expected status code of the response | Optional. The test will fail if the actual status code is different; defaults to 200| No |
|                           | expected response  | expected content of the response | Optional. The test will fail if the actual content (body) of the response is not equal. | No |
|                           | expected response regex | a regex to match against the response | Optional. The keyword will try to match the provided regular expression against the content (body) of the response and will fail if there is no match; currently it is not possible to provide regex matching options. | No |
|                           | expected headers | list of expected response headers | Optional. Same format as the *headers* parameter. The keyword will fail if not all of the expected response headers exist or if they have values different than the expected/specified onesble to provide regex matching options. | No |
|                           | *json path* | *expected value at this json path* | Optional. The argument name should be the actual JSON path, i.e. "$.address.city". If more than one value is found using this JSON path the keyword will succeed if at least one of the values is equal to the expected (argument) value. Currently it is not possible to use the same JSON path more than once. | Yes |

==> testx-http-keywords-0.12.0.tgz: package/README.md <==
testx-http-keywords
=====

A library that extends testx with keywords for sending basic http requests. This library is packaged as a npm package

## How does it work
From the directory of the art code install the package as follows:
```sh
npm install testx-http-keywords --save
```

After installing the package add the keywords to your protractor config file as follows:

```
testx.keywords.add(require('testx-http-keywords'))
```

## Keywords

| Keyword                   | Argument name | Argument value  | Description | Supports repeating arguments |
| ----------------------    | ------------- | --------------- |------------ | ---------------------------- |
| send http [optional request method] request         |               |                 | send a http POST request and check if the response status code is 200 |  |
|                           | url           | relative url to which the request will be sent || No |
|                           | method        | request method  | Optional. Valid values are **get**, **post**, **put** and **delete**. Defaults to **get**. It is also possible to put the methid in the keyword, as in **send http post request** or **send http delete request** instead of providing this argument. | No |
|                           | json          | a valid JSON string that contains the body of the request, will make the Content-Type of the request 'application/json' | Optional. Cannot use it together with **body**. | No |
|                           | body          | a string that contains the body of the request | Optional. Cannot use it together with **json**. | No |
|                           | headers       | custom headers | Optional. Semicolon or new line-separated string of '='-separated key-value pairs. For example "User-Agent=testx;Something-Else='value with spaces'"| No |
|                           | expected status code   | expected status code of the response | Optional. The test will fail if the actual status code is different; defaults to 200| No |
|                           | expected response  | expected content of the response | Optional. The test will fail if the actual content (body) of the response is not equal. | No |
|                           | expected response regex | a regex to match against the response | Optional. The keyword will try to match the provided regular expression against the content (body) of the response and will fail if there is no match; currently it is not possible to provide regex matching options. | No |
|                           | expected headers | list of expected response headers | Optional. Same format as the *headers* parameter. The keyword will fail if not all of the expected response headers exist or if they have values different than the expected/specified onesble to provide regex matching options. | No |
|                           | *json path* | *expected value at this json path* | Optional. The argument name should be the actual JSON path, i.e. "$.address.city". If more than one value is found using this JSON path the keyword will succeed if at least one of the values is equal to the expected (argument) value. Currently it is not possible to use the same JSON path more than once. | Yes |
